@@ -1,12 +1,9 @@
 package Director;
 
+require './t/testlib/CDBase.pm';
+@ISA = 'CDBase';
 use strict;
-use base qw(Class::DBI);
-use File::Temp qw/tempdir/;
 
-my $dir = tempdir( CLEANUP => 1 );
-
-__PACKAGE__->set_db('Main', "DBI:CSV:f_dir=$dir", '', '');
 __PACKAGE__->table('Directors');
 __PACKAGE__->columns('All' => qw/ Name Birthday IsInsane /);
 
