@@ -1,11 +1,9 @@
 package Lazy;
 
+require './t/testlib/CDBase.pm';
+@ISA = 'CDBase';
 use strict;
-use base qw(Class::DBI);
-use File::Temp qw/tempdir/;
-my $dir = tempdir( CLEANUP => 1 );
 
-__PACKAGE__->set_db('Main', "DBI:CSV:f_dir=$dir", '', '');
 __PACKAGE__->table("Lazy");
 __PACKAGE__->columns('Primary', qw(this));
 __PACKAGE__->columns('Essential', qw(opop));
